<?php

namespace Drupal\atsmarttag_domain\Form;

use Drupal\atsmarttag\Form\ATSmartTagSettingsForm;
use Drupal\Core\Asset\LibraryDiscoveryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\file\FileRepositoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Routing\RequestContext;

/**
 * Class DomainSmartTagSettingsForm.
 *
 * @package Drupal\atsmarttag_domain\Form
 */
class DomainSmartTagSettingsForm extends ATSmartTagSettingsForm {

  const ATSMARTTAG_DOMAIN_SETTINGS = 'atsmarttag_domain.settings';

  /**
   * The request context.
   *
   * @var \Drupal\Core\Routing\RequestContext
   */
  protected $requestContext;

  /**
   * Constructs an ATSmartTagSettingsForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory for the form.
   * @param \Drupal\Core\Asset\LibraryDiscoveryInterface $library_discovery
   *   The library discovery service.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\file\FileRepositoryInterface $file_repository
   *   The file repository service.
   * @param \Drupal\Core\Routing\RequestContext $request_context
   *   The request context.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    LibraryDiscoveryInterface $library_discovery,
    EntityTypeManagerInterface $entity_type_manager,
    FileRepositoryInterface $file_repository,
    RequestContext $request_context
  ) {
    parent::__construct($config_factory, $library_discovery, $entity_type_manager, $file_repository);
    $this->requestContext = $request_context;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('library.discovery'),
      $container->get('entity_type.manager'),
      $container->get('file.repository'),
      $container->get('router.request_context')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    $domain_id = $this->getRequest()->get('domain_id');
    return [
      self::ATSMARTTAG_DOMAIN_SETTINGS . '.' . $domain_id,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'atsmarttag_domain_settings_form';
  }

  /**
   * Get configuration.
   * @return \Drupal\Core\Config\Config|\Drupal\Core\Config\ImmutableConfig
   */
  protected function getConfig() {
    $domain_id = $this->getRequest()->get('domain_id');
    return $this->config(
      self::ATSMARTTAG_DOMAIN_SETTINGS . '.' . $domain_id);
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $domain_id = $this->getRequest()->get('domain_id');

    $form['domain'] = [
      '#prefix' => '<p>',
      '#suffix' => '</p>',
      '#markup' => t('Domain: @domain_id', ['@domain_id' => $domain_id]),
      '#weight' => -100,
    ];

    return parent::buildForm($form, $form_state);
  }

  protected function getTagFilename() {
    $domain_id = $this->getRequest()->get('domain_id');
    return 'smarttag.' . $domain_id . '.js';
  }

  protected function getTagLibrary($mode) {
    $domain_id = $this->getRequest()->get('domain_id');
    switch ($mode) {
      case 'generic':
        $library = 'atsmarttag/smarttag.js';
        break;
      case 'url':
        $library = 'atsmarttag/smarttag_url.' . $domain_id;
        break;
      case 'file':
        $library = 'atsmarttag/smarttag_file.' . $domain_id;
        break;
      default:
        $library = '';
    }
    return $library;
  }

}
